@@ -12,6 +12,7 @@ from dipy.reconst.shm import sf_to_sh, sh_to_sf, sph_harm_ind_list
 from dipy.testing.decorators import doctest_skip_parser
 from dipy.utils.optpkg import optional_package
 from dipy.nn.utils import set_logger_level
+from dipy.utils.deprecator import deprecated_params
 
 tf, have_tf, _ = optional_package('tensorflow', min_version='2.0.0')
 if have_tf:
@@ -33,8 +34,9 @@ class HistoResDNN:
     This class is intended for the ResDNN Histology Network model.
     """
 
+    @deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
     @doctest_skip_parser
-    def __init__(self, sh_order=8, basis_type='tournier07', verbose=False):
+    def __init__(self, sh_order_max=8, basis_type='tournier07', verbose=False):
         r"""
         The model was re-trained for usage with a different basis function
         ('tournier07') like the proposed model in [1, 2].
@@ -51,10 +53,11 @@ class HistoResDNN:
 
         Parameters
         ----------
-        sh_order : int, optional
-            Maximum SH order in the SH fit.  For ``sh_order``, there will be
-            ``(sh_order + 1) * (sh_order + 2) / 2`` SH coefficients for a
-            symmetric basis. Default: 8
+        sh_order_max : int, optional
+            Maximum SH order (l) in the SH fit.  For ``sh_order_max``, there
+            will be
+            ``(sh_order_max + 1) * (sh_order_max + 2) / 2`` SH coefficients
+            for a symmetric basis. Default: 8
         basis_type : {'tournier07', 'descoteaux07'}, optional
             ``tournier07`` (default) or ``descoteaux07``.
         verbose : bool (optional)
@@ -78,8 +81,8 @@ class HistoResDNN:
         if not have_tf:
             raise tf()
 
-        self.sh_order = sh_order
-        self.sh_size = len(sph_harm_ind_list(sh_order)[0])
+        self.sh_order_max = sh_order_max
+        self.sh_size = len(sph_harm_ind_list(sh_order_max)[0])
         self.basis_type = basis_type
 
         log_level = 'INFO' if verbose else 'CRITICAL'
@@ -141,7 +144,7 @@ class HistoResDNN:
         ----------
         x_test : np.ndarray
             Array of size (N, M) where M is
-            ``(sh_order + 1) * (sh_order + 2) / 2``.
+            ``(sh_order_max + 1) * (sh_order_max + 2) / 2``.
             N should not be too big as to limit memory usage.
 
         Returns
@@ -179,7 +182,8 @@ class HistoResDNN:
         -------
         pred_sh_coef : np.ndarray (x, y, z, M)
             Predicted fODF (as SH). The volume has matching shape to the input
-            data, but with ``(sh_order + 1) * (sh_order + 2) / 2`` as a last
+            data, but with
+            ``(sh_order_max + 1) * (sh_order_max + 2) / 2`` as a last
             dimension.
 
         """
@@ -218,7 +222,7 @@ class HistoResDNN:
         h_sphere = HemiSphere(xyz=dw_bvecs)
         dw_sh_coef = sf_to_sh(norm_dw_data, h_sphere, smooth=0.0006,
                               basis_type=self.basis_type,
-                              sh_order=self.sh_order)
+                              sh_order_max=self.sh_order_max)
 
         # Flatten and mask the data (N, SH_SIZE) to facilitate chunks
         ori_shape = dw_sh_coef.shape
@@ -236,11 +240,11 @@ class HistoResDNN:
             sphere = get_sphere('repulsion724')
             tmp_sf = sh_to_sf(sh=tmp_sh, sphere=sphere,
                               basis_type=self.basis_type,
-                              sh_order=self.sh_order)
+                              sh_order_max=self.sh_order_max)
             tmp_sf[tmp_sf < 0] = 0
             tmp_sh = sf_to_sh(tmp_sf, sphere, smooth=0.0006,
                               basis_type=self.basis_type,
-                              sh_order=self.sh_order)
+                              sh_order_max=self.sh_order_max)
             flat_pred_sh_coef[i*chunk_size:(i+1)*chunk_size] = tmp_sh
 
         pred_sh_coef = np.zeros(ori_shape)
