@@ -70,7 +70,7 @@ def test_predict_shape_and_masking():
 
 @pytest.mark.skipif(not have_tf, reason='Requires TensorFlow')
 def test_wrong_sh_order_weights():
-    resdnn_model = HistoResDNN(sh_order=6)
+    resdnn_model = HistoResDNN(sh_order_max=6)
     fetch_model_weights_path = get_fnames('histo_resdnn_weights')
     assert_raises(ValueError, resdnn_model.load_model_weights,
                   fetch_model_weights_path)
