@@ -6,14 +6,12 @@ import numpy as np
 from numpy.testing import assert_almost_equal
 
 tf, have_tf, _ = optional_package('tensorflow', min_version='2.0.0')
-tfa, have_tfa, _ = optional_package('tensorflow_addons')
 
-if have_tf and have_tfa:
+if have_tf:
     from dipy.nn.synb0 import Synb0
 
 
-@pytest.mark.skipif(not all([have_tf, have_tfa]), reason='Requires TensorFlow \
-                                                          , TensorFlow_addons')
+@pytest.mark.skipif(not have_tf, reason='Requires TensorFlow')
 def test_default_weights():
     file_names = get_fnames('synb0_test_data')
     input_arr1 = np.load(file_names[0])['b0'][0]
@@ -26,8 +24,7 @@ def test_default_weights():
     assert_almost_equal(results_arr, target_arr, decimal=1)
 
 
-@pytest.mark.skipif(not all([have_tf, have_tfa]), reason='Requires TensorFlow \
-                                                          , TensorFlow_addons')
+@pytest.mark.skipif(not have_tf, reason='Requires TensorFlow')
 def test_default_weights_batch():
     file_names = get_fnames('synb0_test_data')
     input_arr1 = np.load(file_names[0])['b0']
