@@ -1,4 +1,3 @@
-from packaging.version import Version
 import numbers
 import warnings
 
@@ -15,21 +14,23 @@ from dipy.reconst.dti import (TensorModel, fractional_anisotropy,
 from dipy.reconst.multi_voxel import multi_voxel_fit
 from dipy.reconst.utils import _roi_in_volume, _mask_from_roi
 from dipy.sims.voxel import single_tensor
+from dipy.utils.deprecator import deprecated_params
 
 from dipy.utils.optpkg import optional_package
 cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 SH_CONST = .5 / np.sqrt(np.pi)
 
-
-def multi_tissue_basis(gtab, sh_order, iso_comp):
+@deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
+def multi_tissue_basis(gtab, sh_order_max, iso_comp):
     """
     Builds a basis for multi-shell multi-tissue CSD model.
 
     Parameters
     ----------
     gtab : GradientTable
-    sh_order : int
+    sh_order_max : int
+        Maximal spherical harmonics order (l).
     iso_comp: int
         Number of tissue compartments for running the MSMT-CSD. Minimum
         number of compartments required is 2.
@@ -38,29 +39,30 @@ def multi_tissue_basis(gtab, sh_order, iso_comp):
     -------
     B : ndarray
         Matrix of the spherical harmonics model used to fit the data
-    m : int ``|m| <= n``
-        The order of the harmonic.
-    n : int ``>= 0``
-        The degree of the harmonic.
+    m_values : int ``|m_value| <= l_value``
+        The phase factor (m) of the harmonic.
+    l_values : int ``l_value >= 0``
+        The order (l) of the harmonic.
     """
     if iso_comp < 2:
         msg = "Multi-tissue CSD requires at least 2 tissue compartments"
         raise ValueError(msg)
     r, theta, phi = geo.cart2sphere(*gtab.gradients.T)
-    m, n = shm.sph_harm_ind_list(sh_order)
-    B = shm.real_sh_descoteaux_from_index(m, n, theta[:, None], phi[:, None])
-    B[np.ix_(gtab.b0s_mask, n > 0)] = 0.
+    m_values, l_values = shm.sph_harm_ind_list(sh_order_max)
+    B = shm.real_sh_descoteaux_from_index(m_values, l_values,
+                                          theta[:, None], phi[:, None])
+    B[np.ix_(gtab.b0s_mask, l_values > 0)] = 0.
 
     iso = np.empty([B.shape[0], iso_comp])
     iso[:] = SH_CONST
 
     B = np.concatenate([iso, B], axis=1)
-    return B, m, n
+    return B, m_values, l_values
 
 
 class MultiShellResponse:
-
-    def __init__(self, response, sh_order, shells, S0=None):
+    @deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
+    def __init__(self, response, sh_order_max, shells, S0=None):
         """ Estimate Multi Shell response function for multiple tissues and
         multiple shells.
 
@@ -73,8 +75,8 @@ class MultiShellResponse:
         response : ndarray
             Multi-shell fiber response. The ordering of the responses should
             follow the same logic as S0.
-        sh_order : int
-            Maximal spherical harmonics order.
+        sh_order_max : int
+            Maximal spherical harmonics order (l).
         shells : int
             Number of shells in the data
         S0 : array (3,)
@@ -84,36 +86,37 @@ class MultiShellResponse:
         """
         self.S0 = S0
         self.response = response
-        self.sh_order = sh_order
-        self.n = np.arange(0, sh_order + 1, 2)
-        self.m = np.zeros_like(self.n)
+        self.sh_order_max = sh_order_max
+        self.l_values = np.arange(0, sh_order_max + 1, 2)
+        self.m_values = np.zeros_like(self.l_values)
         self.shells = shells
         if self.iso < 1:
-            raise ValueError("sh_order and shape of response do not agree")
+            raise ValueError("sh_order_max and shape of response do not agree")
 
     @property
     def iso(self):
-        return self.response.shape[1] - (self.sh_order // 2) - 1
+        return self.response.shape[1] - (self.sh_order_max // 2) - 1
 
-
-def _inflate_response(response, gtab, n, delta):
+@deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
+def _inflate_response(response, gtab, sh_order_max, delta):
     """Used to inflate the response for the `multiplier_matrix` in the
     `MultiShellDeconvModel`.
     Parameters
     ----------
     response : MultiShellResponse object
     gtab : GradientTable
-    n : int ``>= 0``
-        The degree of the harmonic.
+    sh_order_max : int ``>= 0``
+        The maximal order (l) of the harmonic.
     delta : Delta generated from `_basic_delta`
     """
-    if any((n % 2) != 0) or (n.max() // 2) >= response.sh_order:
+    if any((sh_order_max % 2) != 0) or \
+        (sh_order_max.max() // 2) >= response.sh_order_max:
         raise ValueError("Response and n do not match")
 
     iso = response.iso
-    n_idx = np.empty(len(n) + iso, dtype=int)
+    n_idx = np.empty(len(sh_order_max) + iso, dtype=int)
     n_idx[:iso] = np.arange(0, iso)
-    n_idx[iso:] = n // 2 + iso
+    n_idx[iso:] = sh_order_max // 2 + iso
     diff = abs(response.shells[:, None] - gtab.bvals)
     b_idx = np.argmin(diff, axis=0)
     kernel = response.response / delta
@@ -121,7 +124,7 @@ def _inflate_response(response, gtab, n, delta):
     return kernel[np.ix_(b_idx, n_idx)]
 
 
-def _basic_delta(iso, m, n, theta, phi):
+def _basic_delta(iso, m_value, l_value, theta, phi):
     """Simple delta function
     Parameters
     ----------
@@ -129,24 +132,24 @@ def _basic_delta(iso, m, n, theta, phi):
         Number of tissue compartments for running the MSMT-CSD. Minimum
         number of compartments required is 2.
         Default: 2
-    m : int ``|m| <= n``
-        The order of the harmonic.
-    n : int ``>= 0``
-        The degree of the harmonic.
+    m_value : int ``|m| <= l``
+        The phase factor (m) of the harmonic.
+    l_value : int ``>= 0``
+        The order (l) of the harmonic.
     theta : array_like
        inclination or polar angle
     phi : array_like
        azimuth angle
     """
-    wm_d = shm.gen_dirac(m, n, theta, phi)
+    wm_d = shm.gen_dirac(m_value, l_value, theta, phi)
     iso_d = [SH_CONST] * iso
     return np.concatenate([iso_d, wm_d])
 
 
 class MultiShellDeconvModel(shm.SphHarmModel):
-
+    @deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
     def __init__(self, gtab, response, reg_sphere=default_sphere,
-                 sh_order=8, iso=2, tol=20):
+                 sh_order_max=8, iso=2, tol=20):
         r"""
         Multi-Shell Multi-Tissue Constrained Spherical Deconvolution
         (MSMT-CSD) [1]_. This method extends the CSD model proposed in [2]_ by
@@ -180,8 +183,8 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         reg_sphere : Sphere (optional)
             sphere used to build the regularization B matrix.
             Default: 'symmetric362'.
-        sh_order : int (optional)
-            maximal spherical harmonics order. Default: 8
+        sh_order_max : int (optional)
+            Maximal spherical harmonics order (l). Default: 8
         iso: int (optional)
             Number of tissue compartments for running the MSMT-CSD. Minimum
             number of compartments required is 2.
@@ -217,20 +220,21 @@ class MultiShellDeconvModel(shm.SphHarmModel):
                 msg = """Response must be of shape (3, len(bvals)-1, 4) or be a
                 MultiShellResponse object."""
                 raise ValueError(msg)
-            response = multi_shell_fiber_response(sh_order,
+            response = multi_shell_fiber_response(sh_order_max,
                                                   bvals=bvals,
                                                   wm_rf=response[0],
                                                   gm_rf=response[1],
                                                   csf_rf=response[2])
 
-        B, m, n = multi_tissue_basis(gtab, sh_order, iso)
+        B, m_values, l_values = multi_tissue_basis(gtab, sh_order_max, iso)
 
-        delta = _basic_delta(response.iso, response.m, response.n, 0., 0.)
+        delta = _basic_delta(response.iso, response.m_values,
+                             response.l_values, 0., 0.)
         self.delta = delta
-        multiplier_matrix = _inflate_response(response, gtab, n, delta)
+        multiplier_matrix = _inflate_response(response, gtab, l_values, delta)
 
         r, theta, phi = geo.cart2sphere(*reg_sphere.vertices.T)
-        odf_reg, _, _ = shm.real_sh_descoteaux(sh_order, theta, phi)
+        odf_reg, _, _ = shm.real_sh_descoteaux(sh_order_max, theta, phi)
         reg = np.zeros([i + iso for i in odf_reg.shape])
         reg[:iso, :iso] = np.eye(iso)
         reg[iso:, iso:] = odf_reg
@@ -238,13 +242,13 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         X = B * multiplier_matrix
 
         self.fitter = QpFitter(X, reg)
-        self.sh_order = sh_order
+        self.sh_order_max = sh_order_max
         self._X = X
         self.sphere = reg_sphere
         self.gtab = gtab
         self.B_dwi = B
-        self.m = m
-        self.n = n
+        self.m_values = m_values
+        self.l_values = l_values
         self.response = response
 
     def predict(self, params, gtab=None, S0=None):
@@ -266,8 +270,12 @@ class MultiShellDeconvModel(shm.SphHarmModel):
             X = self._X
         else:
             iso = self.response.iso
-            B, m, n = multi_tissue_basis(gtab, self.sh_order, iso)
-            multiplier_matrix = _inflate_response(self.response, gtab, n,
+            B, m_values, l_values = multi_tissue_basis(gtab,
+                                                       self.sh_order_max,
+                                                       iso)
+            multiplier_matrix = _inflate_response(self.response,
+                                                  gtab,
+                                                  l_values,
                                                   self.delta)
             X = B * multiplier_matrix
 
@@ -427,23 +435,24 @@ class QpFitter:
         fodf_sh = solve_qp(self._P_mat, Q_mat, self._reg_mat, self._h_mat)
         return fodf_sh
 
-
-def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
+@deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
+def multi_shell_fiber_response(sh_order_max, bvals, wm_rf, gm_rf, csf_rf,
                                sphere=None, tol=20, btens=None):
     """Fiber response function estimation for multi-shell data.
 
     Parameters
     ----------
-    sh_order : int
-         Maximum spherical harmonics order.
+    sh_order_max : int
+         Maximum spherical harmonics order (l).
     bvals : ndarray
         Array containing the b-values. Must be unique b-values, like outputted
         by `dipy.core.gradients.unique_bvals_tolerance`.
-    wm_rf : (4, len(bvals)) ndarray
-        Response function of the WM tissue, for each bvals.
-    gm_rf : (4, len(bvals)) ndarray
+    wm_rf : (N-1, 4) ndarray
+        Response function of the WM tissue, for each bvals,
+        where N is the number of unique b-values including the b0.
+    gm_rf : (N-1, 4) ndarray
         Response function of the GM tissue, for each bvals.
-    csf_rf : (4, len(bvals)) ndarray
+    csf_rf : (N-1, 4) ndarray
         Response function of the CSF tissue, for each bvals.
     sphere : `dipy.core.Sphere` instance, optional
         Sphere where the signal will be evaluated.
@@ -465,10 +474,8 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     -------
     MultiShellResponse
         MultiShellResponse object.
-    """
-    NUMPY_1_14_PLUS = Version(np.__version__) >= Version('1.14.0')
-    rcond_value = None if NUMPY_1_14_PLUS else -1
 
+    """
     bvals = np.array(bvals, copy=True)
     if btens is None:
         btens = np.repeat(["LTE"], len(bvals))
@@ -480,8 +487,8 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     evecs[:, 0] = z
     evecs[:2, 1:] = np.eye(2)
 
-    n = np.arange(0, sh_order + 1, 2)
-    m = np.zeros_like(n)
+    l_values = np.arange(0, sh_order_max + 1, 2)
+    m_values = np.zeros_like(l_values)
 
     if sphere is None:
         sphere = default_sphere
@@ -489,16 +496,17 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     big_sphere = sphere.subdivide()
     theta, phi = big_sphere.theta, big_sphere.phi
 
-    B = shm.real_sh_descoteaux_from_index(m, n, theta[:, None], phi[:, None])
+    B = shm.real_sh_descoteaux_from_index(m_values, l_values,
+                                          theta[:, None], phi[:, None])
     A = shm.real_sh_descoteaux_from_index(0, 0, 0, 0)
 
-    response = np.empty([len(bvals), len(n) + 2])
+    response = np.empty([len(bvals), len(l_values) + 2])
 
     if bvals[0] < tol:
         gtab = GradientTable(big_sphere.vertices * 0, btens=btens[0])
         wm_response = single_tensor(gtab, wm_rf[0, 3], wm_rf[0, :3], evecs,
                                     snr=None)
-        response[0, 2:] = np.linalg.lstsq(B, wm_response, rcond=rcond_value)[0]
+        response[0, 2:] = np.linalg.lstsq(B, wm_response, rcond=None)[0]
 
         response[0, 1] = gm_rf[0, 3] / A
         response[0, 0] = csf_rf[0, 3] / A
@@ -509,7 +517,7 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
             wm_response = single_tensor(gtab, wm_rf[i, 3], wm_rf[i, :3], evecs,
                                         snr=None)
             response[i+1, 2:] = np.linalg.lstsq(B, wm_response,
-                                                rcond=rcond_value)[0]
+                                                rcond=None)[0]
 
             response[i+1, 1] = gm_rf[i, 3] * np.exp(-bvalue * gm_rf[i, 0]) / A
             response[i+1, 0] = csf_rf[i, 3] * np.exp(-bvalue * csf_rf[i, 0]) / A
@@ -524,14 +532,14 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
             wm_response = single_tensor(gtab, wm_rf[i, 3], wm_rf[i, :3], evecs,
                                         snr=None)
             response[i, 2:] = np.linalg.lstsq(B, wm_response,
-                                              rcond=rcond_value)[0]
+                                              rcond=None)[0]
 
             response[i, 1] = gm_rf[i, 3] * np.exp(-bvalue * gm_rf[i, 0]) / A
             response[i, 0] = csf_rf[i, 3] * np.exp(-bvalue * csf_rf[i, 0]) / A
 
         S0 = [csf_rf[0, 3], gm_rf[0, 3], wm_rf[0, 3]]
 
-    return MultiShellResponse(response, sh_order, bvals, S0=S0)
+    return MultiShellResponse(response, sh_order_max, bvals, S0=S0)
 
 
 def mask_for_response_msmt(gtab, data, roi_center=None, roi_radii=10,
