@@ -26,62 +26,88 @@ from dipy.utils.tripwire import TripWireError
 
 cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
-fimg, fbvals, fbvecs = get_fnames('small_64D')
-bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
-gtab = gradient_table(bvals, bvecs)
+gtab, gtab_2s, crossing_ref, signal_cross = None, None, None, None
+multi_params, Kref_sphere, DWI = None, None, None
+mevals_cross, angles_cross, frac_cross, kt_cross = None, None, None, None
+dt_sph, evals_sph, kt_sph, params_sph = None, None, None, None
 
-# 2 shells for techniques that requires multishell data
-bvals_2s = np.concatenate((bvals, bvals * 2), axis=0)
-bvecs_2s = np.concatenate((bvecs, bvecs), axis=0)
-gtab_2s = gradient_table(bvals_2s, bvecs_2s)
 
-# Simulation 1. signals of two crossing fibers are simulated
-mevals_cross = np.array([[0.00099, 0, 0], [0.00226, 0.00087, 0.00087],
-                         [0.00099, 0, 0], [0.00226, 0.00087, 0.00087]])
-angles_cross = [(80, 10), (80, 10), (20, 30), (20, 30)]
-fie = 0.49
-frac_cross = [fie*50, (1-fie) * 50, fie*50, (1-fie) * 50]
-# Noise free simulates
-signal_cross, dt_cross, kt_cross = multi_tensor_dki(gtab_2s, mevals_cross,
-                                                    S0=100,
-                                                    angles=angles_cross,
-                                                    fractions=frac_cross,
-                                                    snr=None)
-evals_cross, evecs_cross = decompose_tensor(from_lower_triangular(dt_cross))
-crossing_ref = np.concatenate((evals_cross, evecs_cross[0], evecs_cross[1],
-                               evecs_cross[2], kt_cross), axis=0)
+def setup_module():
+    global gtab, gtab_2s, crossing_ref, signal_cross
+    global multi_params, Kref_sphere, DWI, S0
+    global mevals_cross, angles_cross, frac_cross, kt_cross
+    global dt_sph, evals_sph, kt_sph, params_sph
 
-# Simulation 2. Spherical kurtosis tensor.- for white matter, this can be a
-# biological implausible scenario, however this simulation is useful for
-# testing the estimation of directional apparent kurtosis and the mean
-# kurtosis, since its directional and mean kurtosis ground truth are a constant
-# which can be calculated easily mathematically.
-Di = 0.00099
-De = 0.00226
-mevals_sph = np.array([[Di, Di, Di], [De, De, De]])
-frac_sph = [50, 50]
-signal_sph, dt_sph, kt_sph = multi_tensor_dki(gtab_2s, mevals_sph, S0=100,
-                                              fractions=frac_sph,
-                                              snr=None)
-evals_sph, evecs_sph = decompose_tensor(from_lower_triangular(dt_sph))
-params_sph = np.concatenate((evals_sph, evecs_sph[0], evecs_sph[1],
-                             evecs_sph[2], kt_sph), axis=0)
-# Compute ground truth - since KT is spherical, apparent kurtosis coefficient
-# for all gradient directions and mean kurtosis have to be equal to Kref_sph.
-f = 0.5
-Dg = f*Di + (1-f)*De
-Kref_sphere = 3 * f * (1-f) * ((Di-De) / Dg) ** 2
+    fimg, fbvals, fbvecs = get_fnames('small_64D')
+    bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
+    gtab = gradient_table(bvals, bvecs)
 
-# Simulation 3. Multi-voxel simulations - dataset of four voxels is simulated.
-# Since the objective of this simulation is to see if procedures are able to
-# work with multi-dimensional data all voxels contains the same crossing signal
-# produced in simulation 1.
+    # 2 shells for techniques that requires multishell data
+    bvals_2s = np.concatenate((bvals, bvals * 2), axis=0)
+    bvecs_2s = np.concatenate((bvecs, bvecs), axis=0)
+    gtab_2s = gradient_table(bvals_2s, bvecs_2s)
 
-DWI = np.zeros((2, 2, 1, len(gtab_2s.bvals)))
-DWI[0, 0, 0] = DWI[0, 1, 0] = DWI[1, 0, 0] = DWI[1, 1, 0] = signal_cross
-multi_params = np.zeros((2, 2, 1, 27))
-multi_params[0, 0, 0] = multi_params[0, 1, 0] = crossing_ref
-multi_params[1, 0, 0] = multi_params[1, 1, 0] = crossing_ref
+    # Simulation 1. signals of two crossing fibers are simulated
+    mevals_cross = np.array([[0.00099, 0, 0], [0.00226, 0.00087, 0.00087],
+                            [0.00099, 0, 0], [0.00226, 0.00087, 0.00087]])
+    angles_cross = [(80, 10), (80, 10), (20, 30), (20, 30)]
+    fie = 0.49
+    frac_cross = [fie*50, (1-fie) * 50, fie*50, (1-fie) * 50]
+    S0 = 100
+    # Noise free simulates
+    signal_cross, dt_cross, kt_cross = multi_tensor_dki(gtab_2s, mevals_cross,
+                                                        S0=S0,
+                                                        angles=angles_cross,
+                                                        fractions=frac_cross,
+                                                        snr=None)
+    evals_cross, evecs_cross = decompose_tensor(
+        from_lower_triangular(dt_cross))
+    crossing_ref = np.concatenate((evals_cross, evecs_cross[0], evecs_cross[1],
+                                   evecs_cross[2], kt_cross), axis=0)
+
+    # Simulation 2. Spherical kurtosis tensor.- for white matter, this can be a
+    # biological implausible scenario, however this simulation is useful for
+    # testing the estimation of directional apparent kurtosis and the mean
+    # kurtosis, since its directional and mean kurtosis ground truth are a
+    # constant which can be calculated easily mathematically.
+    Di = 0.00099
+    De = 0.00226
+    mevals_sph = np.array([[Di, Di, Di], [De, De, De]])
+    frac_sph = [50, 50]
+    signal_sph, dt_sph, kt_sph = multi_tensor_dki(gtab_2s, mevals_sph, S0=S0,
+                                                  fractions=frac_sph, snr=None)
+    evals_sph, evecs_sph = decompose_tensor(from_lower_triangular(dt_sph))
+    params_sph = np.concatenate((evals_sph, evecs_sph[0], evecs_sph[1],
+                                evecs_sph[2], kt_sph), axis=0)
+    # Compute ground truth - since KT is spherical, apparent kurtosis
+    # coefficient for all gradient directions and mean kurtosis have to be
+    # equal to Kref_sph.
+    f = 0.5
+    Dg = f*Di + (1-f)*De
+    Kref_sphere = 3 * f * (1-f) * ((Di-De) / Dg) ** 2
+
+    # Simulation 3. Multi-voxel simulations - dataset of four voxels is
+    # simulated. Since the objective of this simulation is to see if
+    # procedures are able to work with multi-dimensional data all voxels
+    # contains the same crossing signal produced in simulation 1.
+
+    DWI = np.zeros((2, 2, 1, len(gtab_2s.bvals)))
+    DWI[0, 0, 0] = DWI[0, 1, 0] = DWI[1, 0, 0] = DWI[1, 1, 0] = signal_cross
+    multi_params = np.zeros((2, 2, 1, 27))
+    multi_params[0, 0, 0] = multi_params[0, 1, 0] = crossing_ref
+    multi_params[1, 0, 0] = multi_params[1, 1, 0] = crossing_ref
+
+
+def teardown_module():
+    global gtab, gtab_2s, crossing_ref, signal_cross
+    global multi_params, Kref_sphere, DWI
+    global mevals_cross, angles_cross, frac_cross, kt_cross
+    global dt_sph, evals_sph, kt_sph, params_sph
+    gtab, gtab_2s, crossing_ref, signal_cross = None, None, None, None
+    multi_params, Kref_sphere, DWI = None, None, None
+    mevals_cross, angles_cross, frac_cross, kt_cross = None, None, None, \
+        None
+    dt_sph, evals_sph, kt_sph, params_sph = None, None, None, None
 
 
 def test_positive_evals():
@@ -110,10 +136,16 @@ def test_split_dki_param():
 def test_dki_fits():
     """ DKI fits are tested on noise free crossing fiber simulates """
 
+    mask_signal_cross = np.ones_like(signal_cross)
+    mask_signal_cross[..., ::2] = 0
+    mask_signal_cross[0] = 1
+
     # OLS fitting
     dkiM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="OLS")
     dkiF = dkiM.fit(signal_cross)
 
+    assert_array_almost_equal(dkiF.model_params, crossing_ref)
+    dkiF = dkiM.fit(signal_cross, mask=mask_signal_cross)
     assert_array_almost_equal(dkiF.model_params, crossing_ref)
 
     # WLS fitting
@@ -146,6 +178,8 @@ def test_dki_fits():
     dki_nlsM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="NLS")
     dki_nlsF = dki_nlsM.fit(signal_cross)
 
+    assert_array_almost_equal(dki_nlsF.model_params, crossing_ref)
+    dki_nlsF = dki_nlsM.fit(signal_cross, mask=mask_signal_cross)
     assert_array_almost_equal(dki_nlsF.model_params, crossing_ref)
 
     # Restore fitting
@@ -155,6 +189,9 @@ def test_dki_fits():
     assert_array_almost_equal(dki_rtF.model_params, crossing_ref)
 
     # testing multi-voxels
+    mask_signal_multi = np.ones_like(DWI[..., 0])
+    mask_signal_multi[1, 1, ...] = 0
+
     dkiF_multi = dkiM.fit(DWI)
     assert_array_almost_equal(dkiF_multi.model_params, multi_params)
 
@@ -164,6 +201,22 @@ def test_dki_fits():
     dkiF_multi = dki_rtM.fit(DWI)
     assert_array_almost_equal(dkiF_multi.model_params, multi_params)
 
+    dkiF_multi = dki_nlsM.fit(DWI)
+    assert_array_almost_equal(dkiF_multi.model_params, multi_params)
+    dkiF_multi = dki_nlsM.fit(DWI, mask=mask_signal_multi)
+    masked_multi_params = multi_params.copy()
+    masked_multi_params[1, 1, ...] = 0
+    assert_array_almost_equal(dkiF_multi.model_params, masked_multi_params)
+
+    # testing return of S0
+    dki_S0M = dki.DiffusionKurtosisModel(gtab_2s, fit_method="WLS",
+                                         return_S0_hat=True)
+    dki_S0F = dki_S0M.fit(signal_cross)
+    dki_S0F_S0 = dki_S0F.model_S0
+
+    assert_array_almost_equal(dki_S0F_S0,
+                              np.full(dki_S0F.model_params.shape[0:-1], S0))
+
 
 def test_apparent_kurtosis_coef():
     """ Apparent kurtosis coefficients are tested for a spherical kurtosis
@@ -484,6 +537,7 @@ def test_compare_MK_method():
 def test_single_voxel_DKI_stats():
     # tests if AK and RK are equal to expected values for a single fiber
     # simulate randomly oriented
+    fie = 0.49
     ADi = 0.00099
     ADe = 0.00226
     RDi = 0
