@@ -32,46 +32,47 @@ from dipy.reconst.shm import (real_sh_descoteaux_from_index, real_sym_sh_basis,
                               spherical_harmonics, anisotropic_power,
                               calculate_max_order, sh_to_sf_matrix, gen_dirac,
                               convert_sh_to_full_basis, convert_sh_from_legacy,
-                              convert_sh_to_legacy, descoteaux07_legacy_msg,
-                              tournier07_legacy_msg)
+                              convert_sh_to_legacy,
+                              convert_sh_descoteaux_tournier,
+                              descoteaux07_legacy_msg, tournier07_legacy_msg)
 
 
 def test_order_from_ncoeff():
     # Just try some out:
-    for sh_order in [2, 4, 6, 8, 12, 24]:
-        m, n = sph_harm_ind_list(sh_order)
-        n_coef = m.shape[0]
-        assert_equal(order_from_ncoef(n_coef), sh_order)
+    for sh_order_max in [2, 4, 6, 8, 12, 24]:
+        m_values, l_values = sph_harm_ind_list(sh_order_max)
+        n_coef = m_values.shape[0]
+        assert_equal(order_from_ncoef(n_coef), sh_order_max)
 
         # Try out full basis
-        m_full, n_full = sph_harm_ind_list(sh_order, True)
+        m_full, l_full = sph_harm_ind_list(sh_order_max, True)
         n_coef_full = m_full.shape[0]
-        assert_equal(order_from_ncoef(n_coef_full, True), sh_order)
+        assert_equal(order_from_ncoef(n_coef_full, True), sh_order_max)
 
 
 def test_sph_harm_ind_list():
-    m_list, n_list = sph_harm_ind_list(8)
-    assert_equal(m_list.shape, n_list.shape)
+    m_list, l_list = sph_harm_ind_list(8)
+    assert_equal(m_list.shape, l_list.shape)
     assert_equal(m_list.shape, (45,))
-    assert_true(np.all(np.abs(m_list) <= n_list))
-    assert_array_equal(n_list % 2, 0)
+    assert_true(np.all(np.abs(m_list) <= l_list))
+    assert_array_equal(l_list % 2, 0)
     assert_raises(ValueError, sph_harm_ind_list, 1)
 
     # Test for a full basis
-    m_list, n_list = sph_harm_ind_list(8, True)
-    assert_equal(m_list.shape, n_list.shape)
+    m_list, l_list = sph_harm_ind_list(8, True)
+    assert_equal(m_list.shape, l_list.shape)
     # There are (sh_order + 1) * (sh_order + 1) coefficients
     assert_equal(m_list.shape, (81,))
-    assert_true(np.all(np.abs(m_list) <= n_list))
+    assert_true(np.all(np.abs(m_list) <= l_list))
 
 
 def test_real_sh_descoteaux_from_index():
     # Tests derived from tables in
     # https://en.wikipedia.org/wiki/Table_of_spherical_harmonics
-    # where real spherical harmonic $Y^m_n$ is defined to be:
-    #    Real($Y^m_n$) * sqrt(2) if m > 0
-    #    $Y^m_n$                 if m == 0
-    #    Imag($Y^m_n$) * sqrt(2) if m < 0
+    # where real spherical harmonic $Y^m_l$ is defined to be:
+    #    Real($Y^m_l$) * sqrt(2) if m > 0
+    #    $Y^m_l$                 if m == 0
+    #    Imag($Y^m_l$) * sqrt(2) if m < 0
 
     rsh = real_sh_descoteaux_from_index
     pi = np.pi
@@ -142,7 +143,8 @@ def test_real_sym_sh_mrtrix():
 
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter("always")
-        basis, m, n = real_sym_sh_mrtrix(8, sphere.theta, sphere.phi)
+        basis, m_values, l_values = real_sym_sh_mrtrix(8, sphere.theta,
+                                                       sphere.phi)
 
     npt.assert_equal(len(w), 2)
     npt.assert_(issubclass(w[0].category, DeprecationWarning))
@@ -164,13 +166,14 @@ def test_real_sym_sh_basis():
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore")
 
-        basis, m, n = real_sym_sh_mrtrix(4, sphere.theta, sphere.phi)
+        basis, m_values, l_values = real_sym_sh_mrtrix(4, sphere.theta,
+                                                       sphere.phi)
 
     expected = basis[:, new_order]
-    expected *= np.where(m == 0, 1., np.sqrt(2))
+    expected *= np.where(m_values == 0, 1., np.sqrt(2))
 
     with warnings.catch_warnings(record=True) as w:
-        descoteaux07_basis, m, n = real_sym_sh_basis(
+        descoteaux07_basis, m_values, l_values = real_sym_sh_basis(
             4, sphere.theta, sphere.phi)
 
     npt.assert_equal(len(w), 2)
@@ -193,13 +196,14 @@ def test_real_sh_descoteaux1():
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore")
-        basis, m, n = real_sym_sh_mrtrix(4, sphere.theta, sphere.phi)
+        basis, m_values, l_values = real_sym_sh_mrtrix(4, sphere.theta,
+                                                       sphere.phi)
 
     expected = basis[:, new_order]
-    expected *= np.where(m == 0, 1., np.sqrt(2))
+    expected *= np.where(m_values == 0, 1., np.sqrt(2))
 
     with warnings.catch_warnings(record=True) as w:
-        descoteaux07_basis, m, n = real_sh_descoteaux(
+        descoteaux07_basis, m_values, l_values = real_sh_descoteaux(
             4, sphere.theta, sphere.phi)
 
     npt.assert_equal(len(w), 1)
@@ -227,14 +231,14 @@ def test_real_sh_tournier():
     # will use a SH basis of orders up to 10 (121 coefficients)
 
     with warnings.catch_warnings(record=True) as w:
-        B, m, n = real_sh_tournier(
+        B, m_values, l_values = real_sh_tournier(
             10, sphere.theta, sphere.phi, full_basis=True)
 
     npt.assert_equal(len(w), 1)
     npt.assert_(issubclass(w[0].category, PendingDeprecationWarning))
     npt.assert_(tournier07_legacy_msg in str(w[0].message))
 
-    invB = smooth_pinv(B, L=np.zeros_like(n))
+    invB = smooth_pinv(B, L=np.zeros_like(l_values))
     sh_coefs = np.dot(invB, sf)
     sf_approx = np.dot(B, sh_coefs)
 
@@ -259,14 +263,14 @@ def test_real_sh_descoteaux2():
     # will use a SH basis of orders up to 10 (121 coefficients)
 
     with warnings.catch_warnings(record=True) as w:
-        B, m, n = real_sh_descoteaux(10, sphere.theta, sphere.phi,
+        B, m_values, l_values = real_sh_descoteaux(10, sphere.theta, sphere.phi,
                                      full_basis=True)
 
     npt.assert_equal(len(w), 1)
     npt.assert_(issubclass(w[0].category, PendingDeprecationWarning))
     npt.assert_(descoteaux07_legacy_msg in str(w[0].message))
 
-    invB = smooth_pinv(B, L=np.zeros_like(n))
+    invB = smooth_pinv(B, L=np.zeros_like(l_values))
     sh_coefs = np.dot(invB, sf)
     sf_approx = np.dot(B, sh_coefs)
 
@@ -283,9 +287,9 @@ def test_sh_to_sf_matrix():
 
         B1, invB1 = sh_to_sf_matrix(sphere)
 
-        B2, m, n = real_sh_descoteaux(4, sphere.theta, sphere.phi)
+        B2, m_values, l_values = real_sh_descoteaux(4, sphere.theta, sphere.phi)
 
-    invB2 = smooth_pinv(B2, L=np.zeros_like(n))
+    invB2 = smooth_pinv(B2, L=np.zeros_like(l_values))
 
     with warnings.catch_warnings():
         warnings.filterwarnings(
@@ -302,7 +306,7 @@ def test_sh_to_sf_matrix():
 
 def test_smooth_pinv():
     hemi = hemi_icosahedron.subdivide(2)
-    m, n = sph_harm_ind_list(4)
+    m_values, l_values = sph_harm_ind_list(4)
 
     with warnings.catch_warnings():
         warnings.filterwarnings(
@@ -310,21 +314,21 @@ def test_smooth_pinv():
             category=PendingDeprecationWarning)
 
         B = real_sh_descoteaux_from_index(
-            m, n, hemi.theta[:, None], hemi.phi[:, None])
+            m_values, l_values, hemi.theta[:, None], hemi.phi[:, None])
 
-    L = np.zeros(len(m))
+    L = np.zeros(len(m_values))
     C = smooth_pinv(B, L)
     D = np.dot(npl.inv(np.dot(B.T, B)), B.T)
     assert_array_almost_equal(C, D)
 
-    L = n * (n + 1) * .05
+    L = l_values * (l_values + 1) * .05
     C = smooth_pinv(B, L)
     L = np.diag(L)
     D = np.dot(npl.inv(np.dot(B.T, B) + L * L), B.T)
 
     assert_array_almost_equal(C, D)
 
-    L = np.arange(len(n)) * .05
+    L = np.arange(len(l_values)) * .05
     C = smooth_pinv(B, L)
     L = np.diag(L)
     D = np.dot(npl.inv(np.dot(B.T, B) + L * L), B.T)
@@ -395,7 +399,7 @@ class TestQballModel:
                 "ignore", message=descoteaux07_legacy_msg,
                 category=PendingDeprecationWarning)
 
-            model = self.model(gtab, sh_order=4, min_signal=1e-5,
+            model = self.model(gtab, sh_order_max=4, min_signal=1e-5,
                                assume_normed=True)
 
         fit = model.fit(signal)
@@ -425,7 +429,7 @@ class TestQballModel:
                 "ignore", message=descoteaux07_legacy_msg,
                 category=PendingDeprecationWarning)
 
-            model = self.model(gtab, sh_order=4, min_signal=1e-5,
+            model = self.model(gtab, sh_order_max=4, min_signal=1e-5,
                                assume_normed=False)
 
         fit = model.fit(signal * 5)
@@ -449,7 +453,7 @@ class TestQballModel:
                 "ignore",  message=descoteaux07_legacy_msg,
                 category=PendingDeprecationWarning)
 
-            model = self.model(gtab, sh_order=4, min_signal=1e-5,
+            model = self.model(gtab, sh_order_max=4, min_signal=1e-5,
                                assume_normed=True)
 
         fit = model.fit(nd_signal)
@@ -483,20 +487,20 @@ class TestQballModel:
                 "ignore", message=descoteaux07_legacy_msg,
                 category=PendingDeprecationWarning)
 
-            model = self.model(gtab, sh_order=4, min_signal=1e-5)
+            model = self.model(gtab, sh_order_max=4, min_signal=1e-5)
 
         assert_equal(model.B.shape[1], 15)
-        assert_equal(max(model.n), 4)
+        assert_equal(max(model.l_values), 4)
 
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore", message=descoteaux07_legacy_msg,
                 category=PendingDeprecationWarning)
 
-            model = self.model(gtab, sh_order=6, min_signal=1e-5)
+            model = self.model(gtab, sh_order_max=6, min_signal=1e-5)
 
         assert_equal(model.B.shape[1], 28)
-        assert_equal(max(model.n), 6)
+        assert_equal(max(model.l_values), 6)
 
     def test_gfa(self):
         signal, gtab, expected = make_fake_signal()
@@ -573,7 +577,7 @@ class TestCsaOdfModel(TestQballModel):
 
 def test_hat_and_lcr():
     hemi = hemi_icosahedron.subdivide(3)
-    m, n = sph_harm_ind_list(8)
+    m_values, l_values = sph_harm_ind_list(8)
 
     with warnings.catch_warnings():
         warnings.filterwarnings(
@@ -581,7 +585,7 @@ def test_hat_and_lcr():
             category=PendingDeprecationWarning)
 
         B = real_sh_descoteaux_from_index(
-            m, n, hemi.theta[:, None], hemi.phi[:, None])
+            m_values, l_values, hemi.theta[:, None], hemi.phi[:, None])
 
     H = hat(B)
     B_hat = np.dot(H, B)
@@ -777,8 +781,8 @@ def test_sf_to_sh():
 
 def test_faster_sph_harm():
 
-    sh_order = 8
-    m, n = sph_harm_ind_list(sh_order)
+    sh_order_max = 8
+    m_values, l_values = sph_harm_ind_list(sh_order_max)
     theta = np.array([1.61491146,  0.76661665,  0.11976141,  1.20198246,
                       1.74066314, 1.5925956,  2.13022055,  0.50332859,
                       1.19868988,  0.78440679, 0.50686938,  0.51739718,
@@ -814,11 +818,11 @@ def test_faster_sph_harm():
                     -3.09857384, -1.06955885, -2.83826831,  1.81932195,
                     2.81296654])
 
-    sh = spherical_harmonics(m, n, theta[:, None], phi[:, None])
-    sh2 = sph_harm_sp(m, n, theta[:, None], phi[:, None])
+    sh = spherical_harmonics(m_values, l_values, theta[:, None], phi[:, None])
+    sh2 = sph_harm_sp(m_values, l_values, theta[:, None], phi[:, None])
 
     assert_array_almost_equal(sh, sh2, 8)
-    sh = spherical_harmonics(m, n, theta[:, None], phi[:, None],
+    sh = spherical_harmonics(m_values, l_values, theta[:, None], phi[:, None],
                              use_scipy=False)
     assert_array_almost_equal(sh, sh2, 8)
 
@@ -990,3 +994,44 @@ def test_convert_sh_to_legacy():
 
     assert_array_almost_equal(converted_coeffs, expected_coeffs, 2)
     assert_raises(ValueError, convert_sh_to_legacy, sh_coeffs, '', True)
+
+
+def test_convert_sh_descoteaux_tournier():
+
+    # case: max degree zero
+    sh_coeffs = np.array([1.54])  # there is only an l=0,m=0 coefficient
+    converted_coeffs = convert_sh_descoteaux_tournier(sh_coeffs)
+    assert_array_equal(converted_coeffs, sh_coeffs)
+
+    # case: max degree 4
+    sh_coeffs = np.array([
+        1,
+        2, 3, 4, 5, 6,
+        7, 8, 9, 10, 11, 12, 13, 14, 15,
+    ], dtype=float)
+    # expected result is that there is a swap m <--> -m
+    expected_coeffs = np.array([
+        1,
+        6, 5, 4, 3, 2,
+        15, 14, 13, 12, 11, 10, 9, 8, 7,
+    ], dtype=float)
+    converted_coeffs = convert_sh_descoteaux_tournier(sh_coeffs)
+    assert_array_equal(converted_coeffs, expected_coeffs)
+
+    # case: max degree 4 but with more axes
+    dim0 = 2
+    dim1 = 3
+    sh_coeffs_grid = np.array(
+        [np.linspace(10*i, 10*i+1, 6) for i in range(6)]
+    ).reshape(dim0, dim1, 6)
+    converted_coeffs_grid = convert_sh_descoteaux_tournier(sh_coeffs_grid)
+    assert_equal(sh_coeffs_grid.shape, converted_coeffs_grid.shape)
+    for i0 in range(dim0):
+        for i1 in range(dim1):
+            shc = sh_coeffs_grid[i0, i1]  # shc is short for "sh_coeffs"
+            converted_coeffs = converted_coeffs_grid[i0, i1]
+            expected_coeffs = np.array([
+                shc[0],
+                shc[5], shc[4], shc[3], shc[2], shc[1],
+            ])
+            assert_array_equal(converted_coeffs, expected_coeffs)
