@@ -6,8 +6,9 @@ from abc import ABC, abstractmethod
 import numpy as np
 
 from dipy.utils.optpkg import optional_package
+from dipy.viz.horizon.util import show_ellipsis
 
-fury, has_fury, setup_module = optional_package('fury', min_version="0.9.0")
+fury, has_fury, setup_module = optional_package('fury', min_version="0.10.0")
 
 if has_fury:
     from fury import ui
@@ -22,6 +23,7 @@ class HorizonUIElement:
     selected_value: Any
     obj: Any
     position = (0, 0)
+    size = ('auto', 'auto')
 
 
 class HorizonTab(ABC):
@@ -57,6 +59,12 @@ class HorizonTab(ABC):
         for element in args:
             self._elements.append(element)
 
+    def on_tab_selected(self):
+        """Implement if require to update something while the tab becomes
+        active.
+        """
+        pass
+
     @property
     @abstractmethod
     def name(self):
@@ -80,10 +88,13 @@ class TabManager:
     tab_ui : TabUI
         Underlying FURY TabUI object.
     """
-    def __init__(self, tabs, win_size, synchronize_slices=False):
+    def __init__(self, tabs, win_size, on_tab_changed=lambda actors: None,
+                 sync_slices=False, sync_volumes=False, sync_peaks=False):
         num_tabs = len(tabs)
         self._tabs = tabs
-        self._synchronize_slices = synchronize_slices
+        self._synchronize_slices = sync_slices
+        self._synchronize_volumes = sync_volumes
+        self._synchronize_peaks = sync_peaks
 
         win_width, _win_height = win_size
 
@@ -99,7 +110,8 @@ class TabManager:
 
         self._tab_ui.on_change = self._tab_selected
 
-        self.tab_changed = lambda actors: None
+        self.tab_changed = on_tab_changed
+
         slices_tabs = list(
             filter(
                 lambda x: x.__class__.__name__ == 'SlicesTab', self._tabs
@@ -111,13 +123,51 @@ class TabManager:
             warnings.warn(msg)
 
         for tab_id, tab in enumerate(tabs):
-            self._tab_ui.tabs[tab_id].title = ' ' + tab.name
             self._tab_ui.tabs[tab_id].title_font_size = 18
             tab.build(tab_id, self._tab_ui)
             if tab.__class__.__name__ == 'SlicesTab':
+                tab.on_volume_change = self.synchronize_volumes
+            if tab.__class__.__name__ in ['SlicesTab', 'PeaksTab']:
                 tab.on_slice_change = self.synchronize_slices
+            if tab.__class__.__name__ in ['SlicesTab', 'SurfaceTab']:
                 self._render_tab_elements(tab_id, tab.elements)
 
+    def handle_text_overflows(self):
+        for tab_id, tab in enumerate(self._tabs):
+            self._handle_title_overflow(
+                tab.name,
+                self._tab_ui.tabs[tab_id].text_block
+            )
+            if tab.__class__.__name__ == 'SlicesTab':
+                self._handle_label_text_overflow(tab.elements)
+
+    def _handle_label_text_overflow(self, elements):
+        for element in elements:
+            if (not element.size[0] == 'auto' and
+                    element.obj.__class__.__name__ == 'TextBlock2D' and
+                    isinstance(element.position, tuple)):
+                element.obj.message = show_ellipsis(
+                    element.selected_value,
+                    element.obj.size[0],
+                    element.size[0])
+
+    def _handle_title_overflow(self, title_text, title_block):
+        """Handle overflow of the tab title and show ellipsis if required.
+
+        Parameters
+        ----------
+        title_text : str
+            Text to be shown on the tab.
+        title_block : TextBlock2D
+            Fury UI element for holding the title of the tab.
+        """
+        tab_text = title_text.split('.', 1)[0]
+        title_block.message = tab_text
+        available_space, _ = self._tab_size
+        text_size = title_block.size[0]
+        max_width = (available_space / len(self._tabs)) - 15
+        title_block.message = show_ellipsis(tab_text, text_size, max_width)
+
     def _render_tab_elements(self, tab_id, elements):
         for element in elements:
             if isinstance(element.position, list):
@@ -134,9 +184,10 @@ class TabManager:
         self._active_tab_id = tab_ui.active_tab_idx
 
         current_tab = self._tabs[self._active_tab_id]
-        if current_tab.__class__.__name__ == 'SlicesTab':
+        current_tab.on_tab_selected()
+        if current_tab.__class__.__name__ in ['SlicesTab', 'SurfaceTab',
+                                              'PeaksTab']:
             self.tab_changed(current_tab.actors)
-            current_tab.on_tab_selected()
 
     def reposition(self, win_size):
         """
@@ -153,7 +204,7 @@ class TabManager:
 
     def synchronize_slices(self, active_tab_id, x_value, y_value, z_value):
         """
-        Synchronize slicers for all the images
+        Synchronize slicers for all the images and peaks.
 
         Parameters
         ----------
@@ -167,19 +218,50 @@ class TabManager:
             z-value of the active slicer
         """
 
-        if not self._synchronize_slices:
+        if not self._synchronize_slices and not self._synchronize_peaks:
             return
 
-        slices_tabs = list(
+        for tab in self._get_non_active_tabs(active_tab_id,
+                                             ['SlicesTab', 'PeaksTab']):
+            tab.update_slices(x_value, y_value, z_value)
+
+    def synchronize_volumes(self, active_tab_id, value):
+        """Synchronize volumes for all the images with volumes.
+
+        Parameters
+        ----------
+        active_tab_id : int
+            tab_id of the action performing tab
+        value : float
+            volume value of the active volume slider
+
+        """
+
+        if not self._synchronize_volumes:
+            return
+
+        for slices_tab in self._get_non_active_tabs(active_tab_id):
+            slices_tab.update_volume(value)
+
+    def _get_non_active_tabs(self, active_tab_id, types=['SlicesTab']):
+        """Get tabs which are not active and slice tabs.
+
+        Parameters
+        ----------
+        active_tab_id : int
+        types : list(str), optional
+
+        Returns
+        -------
+        list
+        """
+        return list(
             filter(
-                lambda x: x.__class__.__name__ == 'SlicesTab'
+                lambda x: x.__class__.__name__ in types
                 and not x.tab_id == active_tab_id, self._tabs
             )
         )
 
-        for slices_tab in slices_tabs:
-            slices_tab.update_slices(x_value, y_value, z_value)
-
     @property
     def tab_ui(self):
         """FURY TabUI object.
