@@ -1,4 +1,5 @@
 import os
+import warnings
 
 import numpy as np
 import numpy.testing as npt
@@ -7,12 +8,13 @@ import pytest
 from dipy.data import DATA_DIR
 from dipy.io.stateful_tractogram import Space, StatefulTractogram
 from dipy.io.utils import create_nifti_header
+from dipy.testing import check_for_warnings
 from dipy.testing.decorators import use_xvfb
 from dipy.tracking.streamline import Streamlines
 from dipy.utils.optpkg import optional_package
 from dipy.testing.decorators import set_random_number_generator
 
-fury, has_fury, setup_module = optional_package('fury', min_version="0.9.0")
+fury, has_fury, setup_module = optional_package('fury', min_version="0.10.0")
 
 if has_fury:
     from fury import window
@@ -33,8 +35,7 @@ def test_horizon_events(rng):
 
     data = 255 * rng.random((197, 233, 189))
     vox_size = (1., 1., 1.)
-
-    images = [(data, affine)]
+    images = [(data, affine, '/test/filename.nii.gz')]
     # images = None
     from dipy.segment.tests.test_bundles import setup_module
     setup_module()
@@ -107,8 +108,7 @@ def test_horizon(rng):
             clusters_lt=np.inf, clusters_gt=0,
             world_coords=True, interactive=False)
 
-    images = [(data, affine)]
-
+    images = [(data, affine, '/test/filename.nii.gz')]
     # tractograms in native coords (not supported for now)
     with npt.assert_raises(ValueError) as ve:
         horizon(tractograms, images=images, cluster=True, cluster_thr=5,
@@ -133,6 +133,21 @@ def test_horizon(rng):
             world_coords=True, interactive=False)
 
 
+@pytest.mark.skipif(skip_it or not has_fury, reason="Needs xvfb")
+def test_horizon_wrong_dtype_images():
+    affine = np.array([[1., 0., 0., -98.],
+                       [0., 1., 0., -134.],
+                       [0., 0., 1., -72.],
+                       [0., 0., 0., 1.]])
+
+    data = np.random.rand(197, 233, 189).astype(np.bool_)
+    images = [(data, affine)]
+    with warnings.catch_warnings(record=True) as l_warns:
+        horizon(images=images, interactive=False)
+        check_for_warnings(l_warns, 'skipping image 1, passed image is not in '
+                           + 'numerical format')
+
+
 @pytest.mark.skipif(skip_it or not has_fury, reason="Needs xvfb")
 @set_random_number_generator(42)
 def test_roi_images(rng):
@@ -141,7 +156,11 @@ def test_roi_images(rng):
     img2[2, 2, 2] = 1
     img3 = np.zeros((5, 5, 5))
     img3[0, :, :] = 1
-    images = [(img1, np.eye(4)), (img2, np.eye(4)), (img3, np.eye(4))]
+    images = [
+        (img1, np.eye(4)),
+        (img2, np.eye(4), '/test/filename.nii.gz'),
+        (img3, np.eye(4), '/test/filename.nii.gz')
+    ]
     show_m = horizon(images=images, return_showm=True)
     analysis = window.analyze_scene(show_m.scene)
     npt.assert_equal(analysis.actors, 0)
@@ -153,6 +172,51 @@ def test_roi_images(rng):
     npt.assert_equal(analysis.actors, 2)
 
 
+@pytest.mark.skipif(skip_it or not has_fury, reason="Needs xvfb")
+@set_random_number_generator(42)
+def test_surfaces(rng):
+    vertices = rng.random((100, 3))
+    faces = rng.integers(0, 100, size=(100, 3))
+    surfaces = [
+        (vertices, faces),
+        (vertices, faces, '/test/filename.pial'),
+        (vertices, faces, '/test/filename.pial')
+    ]
+    show_m = horizon(surfaces=surfaces, return_showm=True)
+    analysis = window.analyze_scene(show_m.scene)
+    npt.assert_equal(analysis.actors, 3)
+
+    vertices = rng.random((100, 4))
+    faces = rng.integers(0, 100, size=(100, 3))
+    surfaces = [
+        (vertices, faces),
+        (vertices, faces, '/test/filename.pial'),
+        (vertices, faces, '/test/filename.pial')
+    ]
+
+    with warnings.catch_warnings(record=True) as l_warns:
+        show_m = horizon(surfaces=surfaces, return_showm=True)
+        analysis = window.analyze_scene(show_m.scene)
+        npt.assert_equal(analysis.actors, 0)
+        check_for_warnings(l_warns, 'Vertices do not have correct shape: ' +
+                           '(100, 4)')
+
+    vertices = rng.random((100, 3))
+    faces = rng.integers(0, 100, size=(100, 4))
+    surfaces = [
+        (vertices, faces),
+        (vertices, faces, '/test/filename.pial'),
+        (vertices, faces, '/test/filename.pial')
+    ]
+
+    with warnings.catch_warnings(record=True) as l_warns:
+        show_m = horizon(surfaces=surfaces, return_showm=True)
+        analysis = window.analyze_scene(show_m.scene)
+        npt.assert_equal(analysis.actors, 0)
+        check_for_warnings(l_warns, 'Faces do not have correct shape: ' +
+                           '(100, 4)')
+
+
 @pytest.mark.skipif(skip_it, reason="Needs xvfb")
 def test_small_horizon_import():
     from dipy.viz import horizon as Horizon
