@@ -91,7 +91,7 @@ plt.plot(signal, label='noiseless')
 plt.plot(signal_noisy, label='with noise')
 plt.legend()
 # plt.show()
-plt.savefig('simulated_signal.png')
+plt.savefig('simulated_signal.png', bbox_inches='tight')
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
